NotLoggedInException class base

Exception thrown when the user is not logged in or when the session has expired, leading to unauthorized access issues.

This class is typically used to indicate that the user needs to log in again, as the current session is no longer valid. It can be thrown when an operation requires user authentication but the user is not logged in.

Implemented types

Constructors

NotLoggedInException()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited